# 20231017_v0.10.4_seasonal_atmospheres_summer

Full production of a test node simulated with a summer atmospheric profile. 
Reconstructed with 
 - training datasets produced with the same atmosphere as for the production.
 - training datasets produced with the standard average winter atmospheric profile.

The goal is to estimate the systematics introduced by using the same average winter atmospheric profile 
in order to analyse all LST data.

The config file was created manually, inspired by the configurations of the production 20230927_v0.10.4_crab_tuned.

Contact : Georgios Voutsinas


